==> hmd-0.4.0.crate: hmd-0.4.0/icon.md <==
# HMD Icons

You can render icons with `[[icon]]` tags. An icon tag looks like this: `[[icon = github, size = 32, color = white]]`.

When an HMD tag is rendered, all the spaces are ignored. Also, it's case insensitive. That means, `[[icon = arrow head up]]`, `[[icon = ArrowHeadUp]]` and `[[icon = Arrow Head Up]]` are the same.

If `color` value is not given, it's default to white. If `size` value is not given, it's default to 24.

## Icon Set

[[center]]

|        Name        |        Icon        |        Made by        |        License        |
|:------------------:|:------------------:|:---------------------:|:---------------------:|
|AlertTriangle|[[icon=AlertTriangle,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowBack|[[icon=ArrowBack,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowDown|[[icon=ArrowDown,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowForward|[[icon=ArrowForward,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowHeadDown|[[icon=ArrowHeadDown,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowHeadLeft|[[icon=ArrowHeadLeft,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowHeadRight|[[icon=ArrowHeadRight,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowHeadUp|[[icon=ArrowHeadUp,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowUpward|[[icon=ArrowUpward,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|At|[[icon=At,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Attach|[[icon=Attach,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Beer|[[icon=Beer,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Bell|[[icon=Bell,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|BellOff|[[icon=BellOff,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Bug|[[icon=Bug,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Bulb|[[icon=Bulb,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|C|[[icon=C,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|Camera|[[icon=Camera,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Car|[[icon=Car,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Cart|[[icon=Cart,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Chip|[[icon=Chip,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Clock|[[icon=Clock,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Close|[[icon=Close,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|CPP|[[icon=CPP,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|CSS|[[icon=CSS,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|Document|[[icon=Document,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Electricity|[[icon=Electricity,size=96,color=white]]|[material](https://fonts.google.com/icons) | Apache 2.0|
|Eye|[[icon=Eye,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|EyeOff|[[icon=EyeOff,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Facebook|[[icon=Facebook,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Fish|[[icon=Fish,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Folder|[[icon=Folder,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Game|[[icon=Game,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Gift|[[icon=Gift,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Github|[[icon=Github,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Glasses|[[icon=Glasses,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Google|[[icon=Google,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|Happy|[[icon=Happy,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Hash|[[icon=Hash,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Heart|[[icon=Heart,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Home|[[icon=Home,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|HTML|[[icon=HTML,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|Image|[[icon=Image,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Info|[[icon=Info,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Instagram|[[icon=Instagram,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Javascript|[[icon=Javascript,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|Key|[[icon=Key,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Linux|[[icon=Linux,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|List|[[icon=List,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Lock|[[icon=Lock,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Maximize|[[icon=Maximize,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Menu|[[icon=Menu,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|MessageSquare|[[icon=MessageSquare,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Mic|[[icon=Mic,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|MicOff|[[icon=MicOff,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Minimize|[[icon=Minimize,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Monitor|[[icon=Monitor,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Music|[[icon=Music,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Navigation|[[icon=Navigation,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Nuclear|[[icon=Nuclear,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Options|[[icon=Options,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Palette|[[icon=Palette,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Pen|[[icon=Pen,size=96,color=white]]|[material](https://fonts.google.com/icons) | Apache 2.0|
|People|[[icon=People,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Person|[[icon=Person,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Phone|[[icon=Phone,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Pin|[[icon=Pin,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Power|[[icon=Power,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Python|[[icon=Python,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|Question|[[icon=Question,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Radio|[[icon=Radio,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Refresh|[[icon=Refresh,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Rust|[[icon=Rust,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|Save|[[icon=Save,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Scissors|[[icon=Scissors,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Search|[[icon=Search,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Settings|[[icon=Settings,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Share|[[icon=Share,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Shield|[[icon=Shield,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ShieldOff|[[icon=ShieldOff,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Skull|[[icon=Skull,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Slash|[[icon=Slash,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Smoke|[[icon=Smoke,size=96,color=white]]|[material](https://fonts.google.com/icons) | Apache 2.0|
|Soccer|[[icon=Soccer,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Star|[[icon=Star,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Terminal|[[icon=Terminal,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|ThumbDown|[[icon=ThumbDown,size=96,color=white]]|[material](https://fonts.google.com/icons) | Apache 2.0|
|ThumbUp|[[icon=ThumbUp,size=96,color=white]]|[material](https://fonts.google.com/icons) | Apache 2.0|
|Trophy|[[icon=Trophy,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|TV|[[icon=TV,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Twitter|[[icon=Twitter,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Umbrella|[[icon=Umbrella,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|University|[[icon=University,size=96,color=white]]|[material](https://fonts.google.com/icons) | Apache 2.0|
|Video|[[icon=Video,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|VideoOff|[[icon=VideoOff,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|VolumeOff|[[icon=VolumeOff,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|VolumeUp|[[icon=VolumeUp,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Water|[[icon=Water,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Wifi|[[icon=Wifi,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|WifiOff|[[icon=WifiOff,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Wine|[[icon=Wine,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Youtube|[[icon=Youtube,size=96,color=white]]|[bootstrap](https://icons.getbootstrap.com/) | MIT|
[[/center]]

## License

Eva, Ion, Dev, and Bootstrap are under MIT License. Google's Material is under Apache 2.0.

==> hmd-0.4.2.crate: hmd-0.4.2/icon.md <==

# HMD Icons

You can render icons with `[[icon]]` tags. An icon tag looks like this: `[[icon = github, size = 32, color = white]]`.

When an HMD tag is rendered, all the spaces are ignored. Also, it's case insensitive. That means, `[[icon = arrow head up]]`, `[[icon = ArrowHeadUp]]` and `[[icon = Arrow Head Up]]` are the same.

If `color` value is not given, it's default to white. If `size` value is not given, it's default to 24.

## Icon Set

[[center]]

|        Name        |        Icon        |        Made by        |        License        |
|:------------------:|:------------------:|:---------------------:|:---------------------:|
|Alert|[[icon=Alert,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowBack|[[icon=ArrowBack,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowDown|[[icon=ArrowDown,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowForward|[[icon=ArrowForward,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowHeadDown|[[icon=ArrowHeadDown,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowHeadLeft|[[icon=ArrowHeadLeft,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowHeadRight|[[icon=ArrowHeadRight,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowHeadUp|[[icon=ArrowHeadUp,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ArrowUpward|[[icon=ArrowUpward,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|At|[[icon=At,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Attach|[[icon=Attach,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Beer|[[icon=Beer,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Bell|[[icon=Bell,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|BellOff|[[icon=BellOff,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Bug|[[icon=Bug,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Bulb|[[icon=Bulb,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|C|[[icon=C,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|Camera|[[icon=Camera,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Car|[[icon=Car,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Cart|[[icon=Cart,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Chip|[[icon=Chip,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Clock|[[icon=Clock,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Close|[[icon=Close,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|CPP|[[icon=CPP,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|CSS|[[icon=CSS,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|Document|[[icon=Document,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Electricity|[[icon=Electricity,size=96,color=white]]|[material](https://fonts.google.com/icons) | Apache 2.0|
|Eye|[[icon=Eye,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|EyeOff|[[icon=EyeOff,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Facebook|[[icon=Facebook,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Fish|[[icon=Fish,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Folder|[[icon=Folder,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Game|[[icon=Game,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Gift|[[icon=Gift,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Github|[[icon=Github,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Glasses|[[icon=Glasses,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Google|[[icon=Google,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|Happy|[[icon=Happy,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Hash|[[icon=Hash,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Heart|[[icon=Heart,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Home|[[icon=Home,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|HTML|[[icon=HTML,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|Image|[[icon=Image,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Info|[[icon=Info,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Instagram|[[icon=Instagram,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Javascript|[[icon=Javascript,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|Key|[[icon=Key,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Linux|[[icon=Linux,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|List|[[icon=List,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Lock|[[icon=Lock,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Maximize|[[icon=Maximize,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Menu|[[icon=Menu,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|MessageSquare|[[icon=MessageSquare,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Mic|[[icon=Mic,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|MicOff|[[icon=MicOff,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Minimize|[[icon=Minimize,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Monitor|[[icon=Monitor,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Music|[[icon=Music,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Navigation|[[icon=Navigation,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Nuclear|[[icon=Nuclear,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Options|[[icon=Options,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Palette|[[icon=Palette,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Pen|[[icon=Pen,size=96,color=white]]|[material](https://fonts.google.com/icons) | Apache 2.0|
|People|[[icon=People,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Person|[[icon=Person,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Phone|[[icon=Phone,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Pin|[[icon=Pin,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Power|[[icon=Power,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Python|[[icon=Python,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|Question|[[icon=Question,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Radio|[[icon=Radio,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Refresh|[[icon=Refresh,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Rust|[[icon=Rust,size=96,color=white]]|[dev_icons](https://devicon.dev/) | MIT|
|Save|[[icon=Save,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Scissors|[[icon=Scissors,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Search|[[icon=Search,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Settings|[[icon=Settings,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Share|[[icon=Share,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Shield|[[icon=Shield,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|ShieldOff|[[icon=ShieldOff,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Skull|[[icon=Skull,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Slash|[[icon=Slash,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Smoke|[[icon=Smoke,size=96,color=white]]|[material](https://fonts.google.com/icons) | Apache 2.0|
|Soccer|[[icon=Soccer,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Star|[[icon=Star,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Terminal|[[icon=Terminal,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|ThumbDown|[[icon=ThumbDown,size=96,color=white]]|[material](https://fonts.google.com/icons) | Apache 2.0|
|ThumbUp|[[icon=ThumbUp,size=96,color=white]]|[material](https://fonts.google.com/icons) | Apache 2.0|
|Trophy|[[icon=Trophy,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|TV|[[icon=TV,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Twitter|[[icon=Twitter,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Umbrella|[[icon=Umbrella,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|University|[[icon=University,size=96,color=white]]|[material](https://fonts.google.com/icons) | Apache 2.0|
|Video|[[icon=Video,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|VideoOff|[[icon=VideoOff,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|VolumeOff|[[icon=VolumeOff,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|VolumeUp|[[icon=VolumeUp,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Water|[[icon=Water,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Wifi|[[icon=Wifi,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|WifiOff|[[icon=WifiOff,size=96,color=white]]|[eva_icons](https://akveo.github.io/eva-icons/) | MIT|
|Wine|[[icon=Wine,size=96,color=white]]|[ion_icons](https://ionic.io/ionicons) | MIT|
|Youtube|[[icon=Youtube,size=96,color=white]]|[bootstrap](https://icons.getbootstrap.com/) | MIT|
[[/center]]

## License

Eva, Ion, Dev, and Bootstrap are under MIT License. Google's Material is under Apache 2.0.
